/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * ElementsCommandLineQuery.cpp
 *
 *  Created on: Oct 25, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "CommandLineUI/Query/CommandLineQuery.hpp"
#include "CommandLineUI/CommandLineParser.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"
#include "Element/element.hpp"
#include "Element/periodentafel.hpp"
#include "World.hpp"

CommandLineDialog::ElementsCommandLineQuery::ElementsCommandLineQuery(Parameter<std::vector<const element*> > &_param, std::string title, std::string _description) :
    Dialog::TQuery<std::vector<const element *> >(_param, title, _description)
{}

CommandLineDialog::ElementsCommandLineQuery::~ElementsCommandLineQuery()
{}

bool CommandLineDialog::ElementsCommandLineQuery::handle() {
  // TODO: vector of ints and removing first is not correctly implemented yet. How to remove from a vector?
  periodentafel *periode = World::getInstance().getPeriode();
  std::vector<int> AllElements;
  if (CommandLineParser::getInstance().vm.count(getTitle())) {
    try {
      AllElements = CommandLineParser::getInstance().vm[getTitle()].as< vector<int> >();
    } catch(boost::bad_any_cast &e) {
      AllElements.clear();
      return false;
    }
    const element *temp_element;
    for (vector<int>::iterator ZRunner = AllElements.begin(); ZRunner != AllElements.end(); ++ZRunner) {
      temp_element = periode->FindElement(*ZRunner);
      ASSERT(temp_element != NULL, "Invalid element specified in ElementCommandLineQuery");
      temp.push_back(temp_element);
    }
    return true;
  }
  return false;
}

